getridofNA: Get rid of NA and replace with numeric value

Description Usage Arguments Value Author(s) Examples

Description

This function is neccessary for 'firstlook' function to run properly. This gets rid of NA values in the desired AOI colunms so that the firstlook function runs smoothly. This function requires the package 'tidyverse'.

Usage

1
getridofNA(dataframe, dataframe$AOI1, dataframe$AOI2)

Arguments

dataframe

The name of the dataframe you are using.

dataframe$AOI1

The column of one of the desired AOIs.

dataframe$AOI2

The column of one of the desired AOIs.

Value

This returns the dataframe as it was before, but replacing NAs with 999 in the desired columns.

Author(s)

Nicole Burke

Examples

1
2
3
4
5
6
7
8
##---- Should be DIRECTLY executable !! ----
##-- ==>  Define data, use random,
##--	or do  help(data=index)  for the standard data sets.

## The function is currently defined as
function (x)
{
  }

nicoleburke/aoianalysis documentation built on Oct. 15, 2020, 4:07 p.m.