Description Usage Arguments Value Author(s) Examples
This function is neccessary for 'firstlook' function to run properly. This gets rid of NA values in the desired AOI colunms so that the firstlook function runs smoothly. This function requires the package 'tidyverse'.
1 | getridofNA(dataframe, dataframe$AOI1, dataframe$AOI2)
|
dataframe |
The name of the dataframe you are using. |
dataframe$AOI1 |
The column of one of the desired AOIs. |
dataframe$AOI2 |
The column of one of the desired AOIs. |
This returns the dataframe as it was before, but replacing NAs with 999 in the desired columns.
Nicole Burke
1 2 3 4 5 6 7 8 | ##---- Should be DIRECTLY executable !! ----
##-- ==> Define data, use random,
##-- or do help(data=index) for the standard data sets.
## The function is currently defined as
function (x)
{
}
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.